|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r76076 - trunk/boost/uuid
From: atompkins_at_[hidden]
Date: 2011-12-19 21:06:21
Author: atompkins
Date: 2011-12-19 21:06:21 EST (Mon, 19 Dec 2011)
New Revision: 76076
URL: http://svn.boost.org/trac/boost/changeset/76076
Log:
ticket #6118
Text files modified:
trunk/boost/uuid/seed_rng.hpp | 5 +++--
1 files changed, 3 insertions(+), 2 deletions(-)
Modified: trunk/boost/uuid/seed_rng.hpp
==============================================================================
--- trunk/boost/uuid/seed_rng.hpp (original)
+++ trunk/boost/uuid/seed_rng.hpp 2011-12-19 21:06:21 EST (Mon, 19 Dec 2011)
@@ -153,8 +153,9 @@
if(random_)
{
- // the cast to void is to suppress warnings
- (void)std::fread( buffer, 1, 20, random_ );
+ // the not_used variable is to suppress warnings
+ size_t not_used = 0;
+ not_used = std::fread( buffer, 1, 20, random_ );
}
// using an uninitialized buffer[] if fopen fails
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk